<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="105"/>
        <source>Video format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="120"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
